@@ -374,11 +374,13 @@ chart_Series <- function(x,
   assign(".chob", cs, .plotEnv)
 
   # handle TA="add_Vo()" as we would interactively FIXME: allow TA=NULL to work
-  if(!is.null(TA) && nchar(TA) > 0) {
-    TA <- parse(text=TA, srcfile=NULL)
-    for(ta in seq_along(TA)) {
+  if(!is.null(TA)){
+    for(i in seq_along(TA)) {
       # evaluate TA in environment from which chart_Series was called
-      cs <- eval(TA[ta], envir = parent.frame())
+      if(nchar(TA[i]) > 0) {
+        ta <- parse(text=TA[i], srcfile=NULL)
+        cs <- eval(ta, envir = parent.frame())
+      }
     }
   }
   assign(".chob", cs, .plotEnv)
@@ -684,24 +686,6 @@ add_WMA <- function(n=10, wts=1:n, on=1, col='green',...) {
   plot_object$add(exp,env=c(lenv, plot_object$Env),expr=TRUE)
   plot_object
 } # }}}
-# add_VMA {{{
-add_VMA <- function(w, ratio=1, on=1, col='green',...) {
-  lenv <- new.env()
-  lenv$add_wma <- function(x, w, ratio, col, ...) {
-    xdata <- x$Env$xdata
-    xsubset <- x$Env$xsubset
-    vma <- VMA(Cl(xdata), w=w, ratio=ratio)[xsubset]
-    lines(1:NROW(xdata[xsubset]), vma, col=col, ...)
-  }
-  mapply(function(name,value) { assign(name,value,envir=lenv) }, names(list(w=w,ratio=ratio,col=col,...)), list(w=w,ratio=ratio,col=col,...))
-  exp <- parse(text=gsub("list","add_wma",as.expression(substitute(list(x=current.chob(),w=w,ratio=ratio,col=col,...)))),
-               srcfile=NULL)
-  plot_object <- current.chob()
-  lenv$xdata <- VMA(Cl(plot_object$Env$xdata),w=w,ratio=ratio)
-  plot_object$set_frame(sign(on)*(abs(on)+1L))
-  plot_object$add(exp,env=c(lenv, plot_object$Env),expr=TRUE)
-  plot_object
-} # }}}
 # add_DEMA {{{
 add_DEMA <- function(n=10, on=1, col='pink', ...) {
   lenv <- new.env()
@@ -1078,6 +1062,99 @@ add_BBands <- function(n=20, maType="SMA", sd=2, on=-1, ...) {
   chob
 } # }}}
 
+# add_ADX {{{
+add_ADX <- function(n = 14, maType = "EMA", on = NA, ...) {
+  lenv <- new.env()
+  lenv$add_adx <- function(x, n, col, ...) {
+    xdata <- x$Env$xdata
+    xsubset <- x$Env$xsubset
+    adx <- ADX(HLC(xdata), n = n, ...)[xsubset]
+    x_axis <- seq_len(NROW(xdata[xsubset]))
+    lines(x_axis, adx$DIp, col = "green", ...)
+    lines(x_axis, adx$DIn, col = "red", ...)
+    lines(x_axis, adx$DX,  col = "black", ...)
+    lines(x_axis, adx$ADX, col = "blue", lty = 2, ...)
+  }
+
+  mapply(function(name, value) {
+           assign(name, value, envir = lenv)
+         }, names(list(n = n, ...)), list(n = n, ...))
+
+  exp <- parse(text = gsub("list",
+                           "add_adx",
+                           as.expression(substitute(list(x = current.chob(),
+                                                         n = n, ...)))),
+               srcfile = NULL)
+  plot_object <- current.chob()
+
+  adx <- ADX(HLC(plot_object$Env$xdata), n = n, ...)
+  lenv$xdata <- adx
+
+  # panel header
+  plot_object$add_frame(ylim = c(0, 1), asp = 0.2)
+  plot_object$next_frame()
+  header_expr <- expression({
+    header <- paste0("ADX(", n, "): ")
+    header_width <- strwidth(header)
+    pad <- strwidth("5")
+    last_values <- round(last(xdata[xsubset]), 2)
+    text(x = c(1,
+               1 + header_width,
+               1 + header_width + pad *  6,
+               1 + header_width + pad * 12,
+               1 + header_width + pad * 19),
+         y = 0.3,
+         labels = c(header,
+                    last_values[, 1],
+                    last_values[, 2],
+                    last_values[, 3],
+                    last_values[, 4]),
+         col = c("black", "green", "red", "black", "blue"),
+         adj = c(0, 0),
+         cex = 0.9,
+         offset = 0,
+         pos = 4)
+  })
+  plot_object$add(header_expr, env = c(lenv, plot_object$Env), expr = TRUE)
+
+  # y-axis grid lines and labels
+  lenv$grid_lines <- function(xdata, xsubset) {
+    axTicksByValue(xdata[xsubset], 10, gt = 3)
+  }
+  y_axis_expr <- expression({
+    segments(1,
+             grid_lines(xdata, xsubset),
+             NROW(xdata[xsubset]),
+             grid_lines(xdata, xsubset),
+             col = theme$grid)
+  })
+  y_label_expr <- expression({
+    text(1 - 1/3 - max(strwidth(grid_lines(xdata, xsubset))),
+         grid_lines(xdata, xsubset),
+         noquote(format(grid_lines(xdata, xsubset), justify = "right")),
+         col = theme$labels,
+         offset = 0,
+         pos = 4,
+         cex = 0.9)
+    text(NROW(xdata[xsubset]) + 1/3,
+         grid_lines(xdata, xsubset),
+         noquote(format(grid_lines(xdata, xsubset), justify = "right")),
+         col = theme$labels,
+         offset = 0,
+         pos = 4,
+         cex = 0.9)
+  })
+
+  # data
+  adx_ylim <- c(0, 1.02 * max(adx[plot_object$Env$xsubset], na.rm = TRUE))
+  plot_object$add_frame(ylim = adx_ylim, asp = 1, fixed = TRUE)
+  plot_object$next_frame()
+
+  exp <- c(y_axis_expr, exp, y_label_expr)
+  plot_object$add(exp, env = c(lenv, plot_object$Env), expr = TRUE)
+  plot_object
+} # }}}
+
 # add_Vo {{{
 add_Vo <- function(...) {
   lenv <- new.env()
